/*
 * pvfs_kernel_config.h copyright (c) 1999 Rob Ross and Phil Carns.
 * all rights reserved.
 *
 * Written by Rob Ross and Phil Carns.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License,
 * or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Contact:  Rob Ross    rbross@parl.clemson.edu
 *           Phil Carns  pcarns@parl.clemson.edu
 */

#ifndef __PVFS_KERNEL_CONFIG_H__
#define __PVFS_KERNEL_CONFIG_H__

/* DEBUGGING VALUES */
enum {
	D_SUPER = 1,  /* superblock calls */
	D_INODE = 2,  /* inode calls */
	D_FILE = 4,  /* file calls */
	D_DIR = 8,  /* directory calls */
	D_LLEV = 16, /* low level calls */
	D_LIB = 32,
	D_UPCALL = 64,
	D_PSDEV = 128,
	D_PIOCTL = 256,
	D_SPECIAL = 512,
	D_TIMING = 1024,
	D_DOWNCALL = 2048
};
 
#ifdef __KERNEL__
#define PDEBUG(mask, format, a...)                                \
  do {                                                            \
  if (pvfs_debug & mask) {                                        \
    printk("(%s, %d): ",  __FILE__, __LINE__);                    \
    printk(format, ## a); }                                       \
  } while (0) ;
#define PERROR(format, a...)                                      \
  do {                                                            \
    printk("(%s, %d): ",  __FILE__, __LINE__);                    \
    printk(format, ## a);                                         \
  } while (0) ;

#else

#define PDEBUG(mask, format, a...)                                \
  do {                                                            \
  if (pvfs_debug & mask) {                                        \
    printf("(%s, %d): ",  __FILE__, __LINE__);                    \
    printf(format, ## a); }                                       \
  } while (0) ;
#define PERROR(format, a...)                                      \
  do {                                                            \
    printf("(%s, %d): ",  __FILE__, __LINE__);                    \
    printf(format, ## a);                                         \
  } while (0) ;
#endif


/* Values:
 * PVFS_MAX_IO_SIZE - maximum buffer size to service at one time.  This
 *   is used to prevent very large transfers from grabbing all available
 *   physical memory.
 * PVFS_OPT_IO_SIZE - value returned on statfs; determines the transfer
 *   size used by many common utilities?  Well, maybe not...we still
 *   seem to be getting 64K transfers.
 * PVFS_DEFAULT_DEBUG_MASK - used in pvfs_mod.c and pvfsd.c as the
 *   default mask for debugging.  This can be changed for the module with
 *   the "debug" parameter on insmod.
 * PVFSD_NOFILE - not currently used; will eventually be the number of
 *   file descriptors the pvfsd allows itself to use
 * PVFSD_MAJOR - major number for pvfsd device file
 */
enum {
	PVFS_MAX_IO_SIZE = 16*1024*1024,
	PVFS_OPT_IO_SIZE = 128*1024, 
	PVFS_DEFAULT_DEBUG_MASK = 0,
	PVFSD_NOFILE = 65536,
	PVFSD_MAJOR = 60 /* experimental number */
};


#endif
