/*
 * copyright (c) 1999 Rob Ross and Phil Carns, all rights reserved.
 *
 * Written by Rob Ross and Phil Carns, funded by Scyld Computing.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License,
 * or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Contact:  Rob Ross    rbross@parl.clemson.edu
 *           Phil Carns  pcarns@parl.clemson.edu
 */

#include <linux/module.h>
#include <linux/types.h>
#include <linux/kernel.h>
#include <linux/sched.h>
#include <linux/fs.h>
#include <linux/stat.h>
#include <linux/errno.h>
#include <linux/locks.h>
#include <asm/segment.h>
#include <asm/uaccess.h>
#include <linux/string.h>

#include <pvfs_kernel_config.h>
#include <pvfs_linux.h>

MODULE_AUTHOR("Rob Ross <rbross@parl.clemson.edu> and Phil Carns <pcarns@parl.clemson.edu>");
MODULE_DESCRIPTION("pvfs: PVFS VFS support module");
MODULE_PARM(debug, "0i"); /* integer, minimum of 0 value */

/* we don't need any symbols exported, so let's keep the ksyms table
 * clean.
 */
EXPORT_NO_SYMBOLS;

static int init_pvfs_fs(void);
int pvfsdev_init(void);
void pvfsdev_cleanup(void);

static int debug=-1;
int pvfs_debug = PVFS_DEFAULT_DEBUG_MASK;

int init_module (void)
{
	int i;

	if (debug > -1) pvfs_debug = debug;

	i = pvfsdev_init();
	if(i)
		return i;
	i = init_pvfs_fs();
		return i;
}

void cleanup_module (void)
{
	unregister_filesystem(&pvfs_fs_type);
	pvfsdev_cleanup();
}

static int init_pvfs_fs(void)
{
	return register_filesystem(&pvfs_fs_type);
}
